==> aliyun-python-sdk-dataworks-public-3.3.6.tar.gz: aliyun-python-sdk-dataworks-public-3.3.6/aliyunsdkdataworks_public/request/v20200518/ApprovePermissionApplyOrderRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class ApprovePermissionApplyOrderRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'ApprovePermissionApplyOrder')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_FlowId(self):
		return self.get_query_params().get('FlowId')

	def set_FlowId(self,FlowId):
		self.add_query_param('FlowId',FlowId)

	def get_ApproveComment(self):
		return self.get_query_params().get('ApproveComment')

	def set_ApproveComment(self,ApproveComment):
		self.add_query_param('ApproveComment',ApproveComment)

	def get_ApproveAction(self):
		return self.get_query_params().get('ApproveAction')

	def set_ApproveAction(self,ApproveAction):
		self.add_query_param('ApproveAction',ApproveAction)

==> aliyun-python-sdk-dataworks-public-4.1.2.tar.gz: aliyun-python-sdk-dataworks-public-4.1.2/aliyunsdkdataworks_public/request/v20200518/ApprovePermissionApplyOrderRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class ApprovePermissionApplyOrderRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'ApprovePermissionApplyOrder')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_FlowId(self): # String
		return self.get_query_params().get('FlowId')

	def set_FlowId(self, FlowId):  # String
		self.add_query_param('FlowId', FlowId)
	def get_ApproveComment(self): # String
		return self.get_query_params().get('ApproveComment')

	def set_ApproveComment(self, ApproveComment):  # String
		self.add_query_param('ApproveComment', ApproveComment)
	def get_ApproveAction(self): # Integer
		return self.get_query_params().get('ApproveAction')

	def set_ApproveAction(self, ApproveAction):  # Integer
		self.add_query_param('ApproveAction', ApproveAction)
